@@ -20,7 +20,7 @@ import youtube_dl
 from bs4 import BeautifulSoup
 from unidecode import unidecode
 
-__version__ = "v1.7.3"
+__version__ = "v1.7.31"
 
 SECTION, SECTION_START, SECTION_END, INFO, COOKIE, COOKIE_STORE, AUTO_LOAD, FETCH_BROWSER_COOKIE = None, None, None, None, None, None, None, None
 s = requests.session()
@@ -66,6 +66,7 @@ class DL:
                     self.login()
 
             except requests.ConnectionError as ex:
+                print(ex.errno)
                 print("[-] Error : Connection failed . Check your internet connection and try again!")
                 sys.exit(1)
 
@@ -255,6 +256,7 @@ class DL:
                             print("[+] Login successful.")
 
                     except requests.ConnectionError as ex:
+                        print(ex.errno)
                         print("[-] Error : Connection failed . Check your internet connection and try again!")
                         sys.exit(1)
 
@@ -321,8 +323,13 @@ class DL:
                 course_name = soup.find('div', attrs={'class': 'course-info'}).find('h4')
 
             elif 'zerotomastery' in self.url:
+
                 soup = BeautifulSoup(data.text, 'html.parser')
-                course_name = soup.find('div', attrs={'class': 'details-container'}).find('h1')
+                try:
+
+                    course_name = soup.find('div', attrs={'class': 'details-container'}).find('h1')
+                except Exception as TypeError:
+                    course_name = None
 
             elif 'nihongowa' in self.url:
                 soup = BeautifulSoup(data.text, 'html.parser')
@@ -436,7 +443,7 @@ class DL:
                     pass
 
                 try:
-                    section = unidecode(section.strip())
+                    section = section.strip() #unidecode(section.strip())
 
                 except UnicodeEncodeError as e:
                     print(e.reason)
